@@ -118,4 +118,4 @@ class ContextUpdater:
         return wrapper
 
     def setup_logs(self, folder, level='DEBUG', rotation='2 GB'):
-        logger.add(folder + f'{self.__name__}.log', level=level, rotation=rotation)
+        logger.add(folder + f'{self.__class__}.log', level=level, rotation=rotation)
